extensions [ 
  gis
  matrix 
]

globals [ 
  seed_used
  initial_farms 
  initial_farmers 
  thiessen 
  myID  
  maxID 
  data_list_unit_revenue 
  data_list_price_A
  data_list_price_B   
  price_A
  price_B              
  tot_production_A
  tot_production_B
  history_production_A
  history_production_B
  history_ave_savings
  history_Full
  history_Between
  history_Dead
  tot_area_A
  tot_area_B
  tot_area_N
  history_area_A
  history_area_B
  history_area_N
  var_A
  var_B
  var_N
  tot_area_A_previous
  tot_area_B_previous
  price_history_A      
  price_history_B
  original_area_B      
  ave_savings          
  result_A
  result_B
  result_N              
  result_D         
  result_F        
  result_P 
  result_S 
  after_shock_A
  after_shock_B
  after_shock_D
  after_shock_F
  after_shock_P
  after_shock_S   
  amount_Dead
  amount_Full
  amount_Between
  total_production
  total_land_use
  helpers
  range_A
  range_B
]   

patches-own [ 
  farmerID 
  my_farmer 
]

breed [ farmers farmer]
breed [ processing_heads processing_head ]
processing_heads-own [
  current_capacity
  min_capacity
  max_capacity
]

farmers-own [  
  ID 
  my_patches 
  area 
  area_A                    
  area_B                    
  area_N
  labour                    
  gravity_x 
  gravity_y
  revenue                   
  p_cost_other_A            
  p_cost_transportation_A   
  profit_A                  
  production_A
  p_cost_other_B             
  p_cost_transportation_B
  profit_B
  production_B
  decision_history          ;;each decision concerning the LU type is recorded, the position in the list represent the time
  memory_length              
  my_history_price_A         
  my_history_price_B        
  savings                        
  decision_A         ;; the result of decision for land use A
  decision_B         ;; the result of decision for land use B
  consumption         
  unit_profit_a
  unit_profit_b
  unit_profit_a_history
  unit_profit_b_history 
  max_potential_profit
  n_a
  n_b
  n_v 
  profit   
  my_spatial_neighbours   ;;added on 08June 2017 Paper 3
  likelihood_to_help
  forced_out
  fully_active
  not_fully_active 
  asker?
  asking_amount
]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup
  clear-all
  use-new-seed
  if user_defined_seed? [use-seed-from-user]
  initialize-farmers-and-farms 
  find-gravity-point
  initialise-landuse
;;;;;  create-processing-company
;;;;;  assign-processing-company-to-farmers
  assign-transportation-cost
  assign-other-cost
  create-spatial-links                
  initialize-interaction-attributes
  reset-savings                   
  initialize-global-variables 
  set-scenario-feedback
  reset-ticks
end

to use-new-seed
  if Seed? = "Fixed" [set seed_used 519156710]
  if Seed? = "Random"[set seed_used new-seed]
  output-print word "Generated seed: " seed_used
  random-seed seed_used
end

to use-seed-from-user
  set seed_used read-from-string user-input "Enter a random seed (an integer):"
  output-print word "User-entered seed: " seed_used  ;; print it out
  random-seed seed_used             ;; use the new seed
end



to initialize-farmers-and-farms
  gis:load-coordinate-system "initial_farmers.prj"
  set initial_farms gis:load-dataset "new_ascii_ra4.asc"
  set initial_farmers gis:load-dataset "initial_farmers.shp"
  set thiessen gis:load-dataset "realy_thiessen.shp"
  gis:set-world-envelope gis:envelope-of initial_farms                                            
  gis:apply-raster initial_farms farmerID 
  
  foreach gis:feature-list-of initial_farmers[ 
    let location gis:location-of (first (first (gis:vertex-lists-of ?))) ;; one "first" doesnt work 
      if not empty? location[ 
        create-farmers 1 [
          set xcor item 0 location
          set ycor item 1 location
          set shape "face neutral"
          set size 1  
          set ID gis:property-value ? "Input_FID"         ;; Input_FID is the farmer's ID                     
          set area gis:property-value ? "count"
          set my_patches no-patches     
          set color random 140
          ;set savings random-normal 10000 1000      
          ;;set savings random-normal 2000 200         
          ;set savings random-normal 10000 2000           
          set labour random-normal 50 5             
          set consumption labour * 25         
          set decision_history [] 
          set unit_profit_a_history []
          set unit_profit_b_history []  
          set forced_out 0
          set fully_active 1
          set not_fully_active 0
          set asker? 0                  
        ] 
     ] 
  ]
  
  ;; 3. establish relationship between farmers and farms based on their ID and farmerID
  let nr_farmers (max [farmerID] of patches + 1)
  ask patches [
    set my_farmer nobody
    foreach n-values nr_farmers [?] [ ;;actually, a for loop from 0 through nr-farmers - 1
      let i ?
      if farmerID = i [
        let this_farmer one-of turtle-set farmers with [ID = i]
        set my_farmer this_farmer
        set pcolor [color] of my_farmer + 25
      ]
    ]
    
   ; let i - 1                  ;; Initialise index 
   ; repeat count farmers [     ;; This line repeats the following loop for a number of times, equal to the number of farmers
   ;   let i i + 1              ;; We increase the index by 1
   ;   if farmerID = i [        ;; We check if the value of i is equal to the farmerID
   ;     let this_farmer one-of turtle-set farmers with [ID = i]
   ;     set my_farmer this_farmer
   ;     set pcolor [color] of my_farmer + 25
   ;   ]
   ; ]
  ]
  
  ;; 4. set attributes for farmers   
  ask farmers [
    foreach n-values nr_farmers [?] [
      let j ?
      if ID = j [
        let these_patches patch-set patches with [farmerID = j]
        set my_patches these_patches
        
      ]
    ]
   ]
end 


to find-gravity-point 
  ;; the gravity point is the mean pxcor and mean pycor of all the patches of the farmer, using it to calculate the distance of the farm 
  ;; to the urban area, and also, move the farmer to this location
  ask farmers [
    set gravity_x mean [pxcor] of my_patches
    set gravity_y mean [pycor] of my_patches
    set xcor gravity_x
    set ycor gravity_y
  ]
end 


to initialise-landuse
 
 ;;;below one farm has either A or B as starting land use, but not mixed farm
;;;;;  ask farmers[
;;;;;    ifelse random-float 1 < ratio_A [
;;;;;      ask my_patches [
;;;;;        set pcolor green]
;;;;;      set area_A area
;;;;;      set area_B 0
;;;;;      ]
;;;;;    [
;;;;;     ask my_patches [
;;;;;       set pcolor red]
;;;;;     set area_A 0
;;;;;     set area_B area
;;;;;     ]
;;;;;  ]
  
 ;;;changed on 19-01-2018, allowing mixed land use at initialisation
 
 ask farmers [
   ifelse random-float 1 > 0.5 [
     let initial_a floor (ratio_A * area)
     let initial_b area - initial_a
     ;ask n-of initial_a my_patches [set pcolor green]
     ;ask n-of initial_b my_patches [set pcolor red]
     set area_A initial_a
     set area_B initial_b
   ]
   [
     let initial_a ceiling (ratio_A * area)
     let initial_b area - initial_a
     ;ask n-of initial_a my_patches [set pcolor green]
     ;ask n-of initial_b my_patches [set pcolor red]
     set area_A initial_a
     set area_B initial_b
     
   ]
 ]
  
            
end 



to assign-transportation-cost
 
      ask farmers [
        set p_cost_transportation_A export_transportation_cost_A
        set p_cost_transportation_B export_transportation_cost_B
      ]

end 

to assign-other-cost
  
  if Heterogeneity? = "no" [
    ask farmers [
      set p_cost_other_A 1
      set p_cost_other_B 1
    ]
  ]
  
  if Heterogeneity? = "other_cost:normal" [
    ask farmers [
      set p_cost_other_A random-normal 0.5 0.1
      ;;set p_cost_other_A random-normal 0.5 0.02   ;; this is for larger heterogeneity test
      set p_cost_other_B random-normal 0.5 0.1 
      ;;set p_cost_other_B random-normal 0.5 0.02   ;;this is for larger heterogeneity test    
    ]
  ]
  
  if Heterogeneity? = "other_cost:uniform" [
    ask farmers [
      set p_cost_other_A random-float 0.785
      set p_cost_other_B random-float 0.785
    ]
  ]


end

to create-spatial-links
    ask farmers [
    let spatial_neighbours min-n-of spatial_links_size other farmers [distance myself]
    create-links-with spatial_neighbours
    set my_spatial_neighbours spatial_neighbours
  ]
  
end 

to initialize-interaction-attributes
  
  if type_interaction = "selfish agents" 
  [
    ask farmers
    [
      set likelihood_to_help 0
    ]
  ]
  
  if type_interaction = "heterogeneous interaction"
  [
    ask farmers
    [
      set likelihood_to_help random-float 1
    ]
  ]
  
  if type_interaction = "altruistic agents"
  [
    ask farmers 
    [
      set likelihood_to_help 1
    ]
  ]
  
end 


to reset-savings
  ;;for example, when ini_savings_par = 1, mean = 500, std = 50
  
  let mean-savings 400 + ini_savings_par * 100
  let std-savings 40 + ini_savings_par * 10
  ;let std-savings 240
  ask farmers [
    
    set savings random-normal mean-savings std-savings
    
  ]
  
end 


to initialize-global-variables 
set price_history_A []
set price_history_B []
set history_production_A []
set history_production_B []
set history_area_A []
set history_area_B []
set history_area_N []
set history_ave_savings []
set history_Full []
set history_Between []
set history_Dead []

;;as a model run only has 100 ticks, if the when_shock is randomlly assigned after 90, the multiple shock scenario will not finish all the shocks
;;therefore, change to 90
if Random_shock? = true [let shock_tick random 90 set when_shock shock_tick ]
end 

to set-scenario-feedback
  
if Scenario_feedback = "NO FEEDBACK" [set which_feedback "NO FEEDBACK"]
if Scenario_feedback = "PEF L" [set which_feedback "PEF(-)" set PEF_strength 5]
if Scenario_feedback = "PEF M" [set which_feedback "PEF(-)" set PEF_strength 20]
if Scenario_feedback = "PEF H" [set which_feedback "PEF(-)" set PEF_strength 35]
if Scenario_feedback = "ABF L" [set which_feedback "ABF(+)" set ABF_strength 6]
if Scenario_feedback = "ABF M" [set which_feedback "ABF(+)" set ABF_strength 25]
if Scenario_feedback = "ABF H" [set which_feedback "ABF(+)" set ABF_strength 44]
if Scenario_feedback = "PEF L ABF L" [set which_feedback "BOTH" set PEF_strength 5 set ABF_strength 6  ]
if Scenario_feedback = "PEF L ABF M" [set which_feedback "BOTH" set PEF_strength 5 set ABF_strength 25 ]
if Scenario_feedback = "PEF L ABF H" [set which_feedback "BOTH" set PEF_strength 5 set ABF_strength 44 ]
if Scenario_feedback = "PEF M ABF L" [set which_feedback "BOTH" set PEF_strength 20 set ABF_strength 6 ]
if Scenario_feedback = "PEF M ABF M" [set which_feedback "BOTH" set PEF_strength 20 set ABF_strength 25]
if Scenario_feedback = "PEF M ABF H" [set which_feedback "BOTH" set PEF_strength 20 set ABF_strength 44]
if Scenario_feedback = "PEF H ABF L" [set which_feedback "BOTH" set PEF_strength 35 set ABF_strength 6 ]
if Scenario_feedback = "PEF H ABF M" [set which_feedback "BOTH" set PEF_strength 35 set ABF_strength 25]
if Scenario_feedback = "PEF H ABF H" [set which_feedback "BOTH" set PEF_strength 35 set ABF_strength 44]
end 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go 
  assign-land-use                            ;; to implement land use decisions made at previous tick
  update-globals-1                           ;; to update land use area used for different land use options
  update-price                               ;; to update prices of crops based on variables: tot_production_A tot_production_B, which are updated at the beginning of this tick, representing harvest of last tick 
  receive-income-pay-expenses                ;; to receive income(check which production value is used!!!), to pay consumption (!!!checklabour used for which year?), production costs (!!!supposedly of previous tick), and put profits into savings 
  ask-for-help
  update-cost                                ;; to update costs, based on land use area (this tick) - land use area (previous tick), the change amount is for this year, should be after receive-income-pay-expenses
  implement-shock                            ;; to reduce the yield of crops
  determine-land-use                         ;; to decide land use activities for next tick
  update-globals-2                           ;; to update production in quantity, and agents'status 
  ;;if ticks > 100 []
  if ticks = 100 [report-simulation-result]
  if ticks = 101 [stop]
  tick
end

to assign-land-use
  
  ;;;;;if ticks = 0 []
  ;;;;; below changed on 18-01-2018
  
  if ticks = 0 [
    ;;there is no decision at the beginning of the run, instead, agents have what they have been initialised
    ask farmers [
      set production_A area_A * unit_production_A 
      set production_B area_B * unit_production_B
    ]
  ]
  
  
  if ticks > 0 [
    
    ask farmers[
      ask my_patches [set pcolor white]
      ask n-of decision_A my_patches [
        set pcolor green]
      ask n-of decision_B my_patches with [pcolor != green] [
        set pcolor red]
      ask n-of (area - decision_A - decision_B) my_patches with [pcolor != green and pcolor != red] [
        set pcolor yellow]
      
      set production_A area_A * unit_production_A  ;; added on 17-01-2018, this production is the amout from the activity of last year, calculate this before both variables are changed during the tick
      set production_B area_B * unit_production_B
      
      set area_A decision_A                        ;; now the area for each crop is updated, this area_A is for the current tick 
      set area_B decision_B
      set area_N area - decision_A - decision_B
      
      if area_A = 0 and area_B = 0 [set forced_out 1 set fully_active 0 set not_fully_active 0]
      if area_A + area_B = area    [set forced_out 0 set fully_active 1 set not_fully_active 0]
      if area_N > 0 and area_N < area       [set forced_out 0 set fully_active 0 set not_fully_active 1]
    ]
    
  ]
end

to update-globals-1
  set tot_area_A_previous tot_area_A                                             ;; tot_area_A_previous is used in update-cost, as the difference in the area between current and previous determined the amount of cost change
  set tot_area_B_previous tot_area_B
  
  set tot_production_B sum [production_B] of farmers                             ;; moved from update-globals-2 to this block, because of update sequence issues, on 17-01-2018
  set tot_production_A sum [production_A] of farmers                             ;; moved from update-globals-2 to this block, because of update sequence issues, on 17-01-2018
  ;;ATTENTION fput is to put in the list to the beginning of the list            ;; moved from update-globals-2 to this block, because of update sequence issues, on 17-01-2018
  set history_production_A fput tot_production_A history_production_A            ;; moved from update-globals-2 to this block, because of update sequence issues, on 17-01-2018
  set history_production_B fput tot_production_B history_production_B            ;; moved from update-globals-2 to this block, because of update sequence issues, on 17-01-2018
  
  set tot_area_A count patches with [pcolor = green]                             ;; now tot_area_A is for the current situation
  set tot_area_B count patches with [pcolor = red]
  set tot_area_N count patches with [pcolor = yellow] 
  
  set history_area_A fput tot_area_A history_area_A  
  set history_area_B fput tot_area_B history_area_B
  set history_area_N fput tot_area_N history_area_N
  
  
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; here 10 can be changed;;;;
  ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;
  if ticks >= 10 [
    let sample_A sublist history_area_A 0 10
    let sample_B sublist history_area_B 0 10
    let sample_N sublist history_area_N 0 10
    set var_A variance sample_A
    set var_B variance sample_B
    set var_N variance sample_N
  ]
end 



to update-price

                                                                                                                                                                                                                                                                            
   
   ;;from 0 to 66, when PEF_strength = 66, price will become almost zero when whole area is used for one land use
   ;;theoretically, when PEF_strength = 92, the slope of the price curve will be 45 degree, but when production is 4.25 * 10^5, the price is already 0, and price will become negative when production goes further up
   
   ifelse which_feedback = "PEF(-)" or which_feedback = "BOTH" [set dynamic_price? true][set dynamic_price? false]
    
    if dynamic_price? = true
     [
       if which_land_use = "A" [
         set price_A -1 * (0.08 + PEF_strength * 0.01) * 10 ^ -5 * tot_production_A + 3.1 + 0.0125 * PEF_strength
         set price_B fixed_price_B
       ]
       

       if which_land_use = "B" [
         set price_B -1 * (0.08 + PEF_strength * 0.01) * 10 ^ -5 * tot_production_B + 3.1 + 0.0125 * PEF_strength
         set price_A fixed_price_A
       ]
       
       if which_land_use = "BOTH" [
         set price_A -1 * (0.08 + PEF_strength * 0.01) * 10 ^ -5 * tot_production_A + 3.1 + 0.0125 * PEF_strength
         set price_B -1 * (0.08 + PEF_strength * 0.01) * 10 ^ -5 * tot_production_B + 3.1 + 0.0125 * PEF_strength
         ]
     ]
   
   
   ;;;;;if which_feedback = "ABF(+)" or which_feedback = "NO FEEDBACK"
   if dynamic_price? = false
   [
     ;;fill in the action here
     ;;set both prices as their initial price--->figure this out
     set price_A fixed_price_A
     set price_B fixed_price_B
   ]
   


   
  
end 





;;added on 11-06-2017, to add shocks to the systems for resilience testing 
to implement-shock
  if type_shock = "no_shock" [
    
    
  ]
  
    let change_factor 0
    if shock_strength = "low" [set change_factor 0.2]
    if shock_strength = "medium" [set change_factor 0.4]
    if shock_strength = "high" [set change_factor 0.8]
    
  if type_shock = "once_productivity" [

    
    
    if ticks = when_shock [
      set unit_production_A unit_production_A * (1 - change_factor) 
      set unit_production_B unit_production_B * (1 - change_factor)
    ]
    if ticks = when_shock + 1 [
      set unit_production_A unit_production_A * 1 / (1 - change_factor)
      set unit_production_B unit_production_B * 1 / (1 - change_factor)    ;;turn it back in the next step 
  ]
]
  
  if type_shock = "series_productivity" [
    
    if ticks = when_shock [
      set unit_production_A unit_production_A * (1 - change_factor)  ;;assuming an 80% productivity loss 
      set unit_production_B unit_production_B * (1 - change_factor)
    ]
    
    
    if ticks = when_shock + 1 [
      set unit_production_A unit_production_A * 1 / (1 - change_factor)
      set unit_production_B unit_production_B * 1 / (1 - change_factor)    ;;turn it back in the next step 
  ]
    
    if ticks = when_shock + 3 [
      set unit_production_A unit_production_A * (1 - change_factor)  ;;assuming an 80% productivity loss 
      set unit_production_B unit_production_B * (1 - change_factor)
    ]
    
    if ticks = when_shock + 4 [
      set unit_production_A unit_production_A * 1 / (1 - change_factor)
      set unit_production_B unit_production_B * 1 / (1 - change_factor)    ;;turn it back in the next step 
    ]
    
    if ticks = when_shock + 6 [
      set unit_production_A unit_production_A * (1 - change_factor)  ;;assuming an 80% productivity loss 
      set unit_production_B unit_production_B * (1 - change_factor)
    
    ]
    
    if ticks = when_shock + 7 [
      set unit_production_A unit_production_A * 1 / (1 - change_factor)
      set unit_production_B unit_production_B * 1 / (1 - change_factor)    ;;turn it back in the next step 
    ]
 
  
]
  
end 


to receive-income-pay-expenses
    ask farmers [
      ;;;;;set profit_A area_A * unit_production_A * (price_A - p_cost_other_A - p_cost_transportation_A)   ;; unit_production might have changed due to the shock implemented, also, area_A is also this year's situation, but we are calculating production from last year
      ;;;;;set production_A area_A * unit_production_A  ;;this should be done before area_A and unit_production_A is updated at this tick
      ;;;;;set profit_B area_B * unit_production_B * (price_B - p_cost_other_B - p_cost_transportation_B)
      ;;;;;set production_B area_B * unit_production_B
      
      
      ;;;below, modified on 17 01 2018, due to update sequence issues, the logic is checked , both prices and costs are for the crops of last tick, but only get paid, and paid at current tick 
      set profit_A production_A * (price_A - p_cost_other_A - p_cost_transportation_A)    
      set profit_B production_B * (price_B - p_cost_other_B - p_cost_transportation_B)
      set consumption (area_A * required_labour_A + area_B * required_labour_B) * 25    ;; here area_A is for this tick, also for area_B                   
      set savings savings + profit_A + profit_B - consumption
  ]
end 
 


to update-cost

    ifelse which_feedback = "ABF(+)" or which_feedback = "BOTH" [ set scale_economy true][set scale_economy false]
    
    if scale_economy = true and ticks > 0 [
      let area_change_A tot_area_A - tot_area_A_previous ;;print "area_change_A" print area_change_A
      let area_change_B tot_area_B - tot_area_B_previous ;;print "area_change_B" print area_change_B
      
      ask farmers [
        ;; from 0 to 84, ABF_strength can be maximumlly 1, when ABF_strength = 84
        set range_A 0.16 + ABF_strength * 0.01
        set range_B 0.16 + ABF_strength * 0.01
        if which_land_use = "A" or which_land_use = "BOTH" [
        set p_cost_other_A p_cost_other_A - (area_change_A * range_A / 10506)]
        if which_land_use = "B" or which_land_use = "BOTH" [
        set p_cost_other_B p_cost_other_B - (area_change_B * range_B / 10506)]
         
      ]
      
    ]
    
    ;;if scale_economy is false, simply no update on those costs. so there is no need to write code for this condition 
end 


to ask-for-help
;; Note1: how to determine those who need help? it can be not even smaller than 0, but just not enough to continue with farming production costs
;; Note2: remember to update the helped and helper on each of their financial conditions, cause this influence the next step to determine land use for next year
  if type_interaction != "selfish agents"
  [
    ;;first determine who need help and how much they need
    ask farmers
     [
       ;;if savings < p_cost_other_A + p_cost_transportation_A and savings < p_cost_other_B + p_cost_transportation_B 
       ;;;; the code above does not generate any farmers in trouble
       ;;;; instead, use land use to judge if they need help instead of savings
       
       if forced_out = 1 or not_fully_active = 1
       
       [
         
         ;;the current one being asked is in need, make him ask for help, and after the help, update both their conditions
         ;;for the asker, determine how much to ask for, maybe first to do this, then have another function to implement the asking part
         ;;for the asked, determine how much in total they have
       
       set asker? 1
       ;;let deficit abs profit_A + profit_B
       ;;;;the code above does not generate a positive amount of money, their profit a plus b can be both zero
       let cost_A p_cost_other_A + p_cost_transportation_A
       let cost_B p_cost_other_B + p_cost_transportation_B
       let hypothesis_cost min list cost_A cost_B
       let deficit area_N *  hypothesis_cost * unit_production_A  ;; A or B doesnot matter as they have the same
       
       
       ;;below, a stronger link will make the asking amount higher, as close as to the deficit (when strength_links = 10) 
       set asking_amount deficit * (0.5 + 0.05 * strength_links)
      
       ;;if savings < 0 [ ;then the asking amount should be the deficit + money needed for next year production
       ;;   set asking_amount abs profit_A + profit_B
       ;;  ]
       ;;if savings >= 0 [
       ;; ]
       
       ]
     ]

     ;;the following block only allows help to be made when the provider has more than enough to cover their own expenses.
     ;; when degree of ties is considered, think how to change the codes acoordingly
     ask farmers with [asker? = 1] [
       
       let asking_farmer self
       let check_amount asking_amount
       
       ask max-one-of my_spatial_neighbours [savings] 
       [
         if savings - consumption > check_amount and likelihood_to_help >= random-float 1
          [ ;; then provide help, cause my savings is enough to cover my next consumption, remember to update immediately for both
           set helpers helpers + 1
           set savings savings - check_amount
           ask asking_farmer [
             set savings savings + asking_amount
             set asker? 0
             set asking_amount 0]
   
          ]
       ]
      ]
  ]
   
end 



to determine-land-use


ask farmers [
    let cost_A p_cost_other_A + p_cost_transportation_A
    let cost_B p_cost_other_B + p_cost_transportation_B
    set unit_profit_a (price_A - cost_A) * unit_production_A
    set unit_profit_b (price_B - cost_B) * unit_production_B
    ;set unit_profit_a_history fput unit_profit_a unit_profit_a_history
    ;set unit_profit_b_history fput unit_profit_b unit_profit_b_history


;;;;;;;;;brude force method of maximization
let i -1     ;; Index i will represent number of patches for land-use A
;let j -1     ;; Index j will represent number of patches for land-use B
set max_potential_profit 0
set decision_A 0
set decision_B 0
repeat (area + 1) [      ;; ntot : total number of patches of farm.. This loops over all values for n_a (0 to ntot)
  set i i + 1      ;; We set a new value for the number of patches for land-use A
  ;print i
  let j -1
  repeat (area + 1 - i) [   ;; Loops over all remaining possible values for n_b (0 to ntot - n_a)
    
    set j j + 1 
    ;print j
    set n_a i
    set n_b j
    set n_v (area - n_a - n_b)
    
    ;; Now you can do the required computations, which will be looped over all possible options
    
    set profit n_a * (price_A - cost_A) * unit_production_A + n_b * (price_B - cost_B) * unit_production_B
    if profit > max_potential_profit and n_a * required_labour_A + n_b * required_labour_B <= labour and n_a * unit_production_A * cost_A + n_b * unit_production_B * cost_B <= savings
    [
      set max_potential_profit profit
      set decision_A n_a
      set decision_B n_b
    ]
  ]
]



]


end 

to determine-A
    let cost_A p_cost_other_A + p_cost_transportation_A
    let cost_B p_cost_other_B + p_cost_transportation_B
    set unit_profit_a (price_A - cost_A) * unit_production_A
    set unit_profit_b (price_B - cost_B) * unit_production_B
    let max_area_a_labour labour / required_labour_A
    let max_area_a_savings savings / cost_A
    let max_area_a_land area
    set decision_A floor min (list max_area_a_labour max_area_a_savings max_area_a_land)
    set decision_B 0
    set decision_history lput "A" decision_history 
end 

to determine-B
    let cost_A p_cost_other_A + p_cost_transportation_A
    let cost_B p_cost_other_B + p_cost_transportation_B
    set unit_profit_a (price_A - cost_A) * unit_production_A
    set unit_profit_b (price_B - cost_B) * unit_production_B
    let max_area_b_labour labour / required_labour_B
    let max_area_b_savings savings / cost_B
    let max_area_b_land area
    set decision_B floor min (list max_area_b_labour max_area_b_savings max_area_b_land)
    set decision_A 0
    set decision_history lput "B" decision_history
end 




to update-globals-2
;;;;;  set tot_production_B sum [production_B] of farmers  
;;;;;  set tot_production_A sum [production_A] of farmers 
;;;;;  
;;;;;  ;;ATTENTION fput is to put in the list to the beginning of the list 
;;;;;  set history_production_A fput tot_production_A history_production_A
;;;;;  set history_production_B fput tot_production_B history_production_B
  
  ;;set ave_savings mean [savings] of farmers 
  ifelse any? farmers with [forced_out != 1] [
   set ave_savings mean [savings] of farmers with [forced_out != 1] 
   ];;only take into account active farmers
   [set ave_savings 0]
   
  set amount_Dead count farmers with [forced_out = 1]
  set amount_Full count farmers with [fully_active = 1]
  set amount_Between count farmers with [not_fully_active = 1]
  
  set total_production tot_production_A + tot_production_B
  set total_land_use tot_area_A + tot_area_B
  
  set history_ave_savings fput ave_savings history_ave_savings
  set history_Full fput amount_Full history_Full
  set history_Between fput amount_Between history_Between
  set history_Dead fput amount_Dead history_Dead
  
  if type_shock != "no_shock"
  [
    let after_shock_tick when_shock
    if type_shock = "once_productivity" [set after_shock_tick after_shock_tick + 1]
    if type_shock = "series_productivity" [set after_shock_tick after_shock_tick + 8]
    if ticks = after_shock_tick 
    [
      set  after_shock_A tot_area_A 
      set  after_shock_B tot_area_B 
      set  after_shock_D amount_Dead
      set  after_shock_F amount_Full
      set  after_shock_P amount_Between
      set  after_shock_S ave_savings
    ]
    
  ]
end 

to report-simulation-result
  set result_A mean sublist history_area_A 0 10
  set result_B mean sublist history_area_B 0 10
  set result_N mean sublist history_area_N 0 10
  set result_S mean sublist history_ave_savings 0 10
  set result_F mean sublist history_Full 0 10
  set result_P mean sublist history_Between 0 10
  set result_D mean sublist history_Dead 0 10
  ;;;new codes on 26-03-2016 
end 
@#$#@#$#@
GRAPHICS-WINDOW
72
27
641
622
-1
-1
5.4804
1
10
1
1
1
0
0
0
1
0
101
0
102
0
0
1
ticks
30.0

SLIDER
76
871
248
904
ratio_A
ratio_A
0
1
0.5
0.01
1
NIL
HORIZONTAL

INPUTBOX
267
871
365
931
export_transportation_cost_A
1.1
1
0
Number

INPUTBOX
375
870
472
930
export_transportation_cost_B
1.1
1
0
Number

CHOOSER
78
913
252
958
Heterogeneity?
Heterogeneity?
"no" "other_cost:normal" "other_cost:uniform"
1

BUTTON
72
630
139
663
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
147
631
210
664
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
218
631
281
664
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
85
1209
243
1242
dynamic_price?
dynamic_price?
1
1
-1000

INPUTBOX
267
933
366
993
unit_production_A
50
1
0
Number

INPUTBOX
374
933
474
993
unit_production_B
50
1
0
Number

INPUTBOX
480
933
588
993
required_labour_A
3
1
0
Number

INPUTBOX
595
933
699
993
required_labour_B
2
1
0
Number

PLOT
71
677
271
827
Prices
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"Crop A" 1.0 0 -10899396 true "" "plot price_A"
"Crop B" 1.0 0 -2674135 true "" "plot price_B"

PLOT
274
678
474
828
Production costs
NIL
NIL
0.0
10.0
0.0
3.0
true
false
"" ""
PENS
"other a" 1.0 0 -10899396 true "" "plot mean [p_cost_other_A] of farmers"
"other b" 1.0 0 -2674135 true "" "plot mean [p_cost_other_B] of farmers"
"trans a" 1.0 0 -13840069 true "" ""
"pen-3" 1.0 0 -955883 true "" ""

PLOT
483
677
683
827
Area of land use 
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -2674135 true "" "plot tot_area_B"
"pen-1" 1.0 0 -10899396 true "" "plot tot_area_A"
"pen-2" 1.0 0 -1184463 true "" "plot tot_area_N"

PLOT
705
677
905
827
Mean Savings
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot ave_savings"

PLOT
914
674
1103
828
Crop productions
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -10899396 true "" "plot tot_production_A"
"pen-1" 1.0 0 -2674135 true "" "plot tot_production_B"

SWITCH
85
1250
242
1283
scale_economy
scale_economy
1
1
-1000

OUTPUT
289
628
636
670
12

SWITCH
796
11
984
44
user_defined_seed?
user_defined_seed?
1
1
-1000

INPUTBOX
259
1356
430
1416
PEF_strength
35
1
0
Number

INPUTBOX
81
1358
254
1418
ABF_strength
44
1
0
Number

CHOOSER
85
1109
226
1154
which_feedback
which_feedback
"ABF(+)" "PEF(-)" "BOTH" "NO FEEDBACK"
3

CHOOSER
85
1160
223
1205
which_land_use
which_land_use
"A" "B" "BOTH"
2

INPUTBOX
170
965
249
1025
fixed_price_B
3.1
1
0
Number

INPUTBOX
78
965
160
1025
fixed_price_A
3.1
1
0
Number

CHOOSER
673
151
844
196
type_shock
type_shock
"no_shock" "once_productivity" "series_productivity"
0

INPUTBOX
268
1002
423
1062
spatial_links_size
5
1
0
Number

INPUTBOX
437
1002
592
1062
strength_links
10
1
0
Number

INPUTBOX
484
868
639
928
ini_savings_par
20
1
0
Number

MONITOR
1121
675
1208
728
NIL
helpers
0
1
13

INPUTBOX
260
1207
412
1267
when_shock
44
1
0
Number

CHOOSER
648
11
786
56
Seed?
Seed?
"Random" "Fixed"
0

SWITCH
261
1165
424
1198
Random_shock?
Random_shock?
0
1
-1000

TEXTBOX
87
1288
237
1352
These two switches will automatically be decided by specifying \"which_feedback\"
13
0.0
1

TEXTBOX
265
1273
415
1337
when_shock will automatically be decided when Random_shock? is true
13
0.0
1

CHOOSER
673
209
846
254
type_interaction
type_interaction
"selfish agents" "heterogeneous interaction" "altruistic agents"
0

CHOOSER
261
1118
399
1163
shock_strength
shock_strength
"low" "medium" "high"
2

PLOT
673
352
1196
591
Resilience Indicators
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Land use A" 1.0 0 -10899396 true "" "plot tot_area_A"
"Land use B" 1.0 0 -2674135 true "" "plot tot_area_B"
"Idling land" 1.0 0 -1184463 true "" "plot tot_area_N"
"Fully active" 1.0 0 -6459832 true "" "plot amount_Full"
"Partially active" 1.0 0 -13345367 true "" "plot amount_Between"
"Bankrupted" 1.0 0 -5825686 true "" "plot amount_Dead"
"Financial resources" 1.0 0 -2064490 true "" "plot ave_savings"

CHOOSER
674
264
846
309
Scenario_feedback
Scenario_feedback
"NO FEEDBACK" "PEF L" "PEF M" "PEF H" "ABF L" "ABF M" "ABF H" "PEF L ABF L" "PEF L ABF M" "PEF L ABF H" "PEF M ABF L" "PEF M ABF M" "PEF M ABF H" "PEF H ABF L" "PEF H ABF M" "PEF H ABF H"
0

TEXTBOX
660
75
810
97
Model exploration
18
0.0
1

TEXTBOX
660
98
810
146
The exploration was based on the changes in these mechanisms
13
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment1_external_price_change" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="30"/>
    <metric>tot_area_B</metric>
    <enumeratedValueSet variable="price_of_B">
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B_fluctuating growth20.txt&quot;"/>
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B_fluctuating growth21.txt&quot;"/>
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B_fluctuating growth22.txt&quot;"/>
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B_fluctuating growth23.txt&quot;"/>
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B_fluctuating growth24.txt&quot;"/>
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B_fluctuating growth25.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_external_B">
      <value value="2.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy_target_ratio">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_of_A">
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_A.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Heterogeneity?">
      <value value="&quot;other_cost:normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transportation_cost_B">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_A">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation-cost_B">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_active?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_default?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dynamic_price_B?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ratio_A">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_A">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_B">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial_lag?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transportation_cost_A">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold_environment">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishment">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CostReduction-InitialRatio-PriceSensitivity10-5-10" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>seed_used</metric>
    <metric>result_A</metric>
    <metric>result_B</metric>
    <metric>result_N</metric>
    <metric>var_A</metric>
    <metric>var_B</metric>
    <metric>var_N</metric>
    <metric>ave_savings</metric>
    <metric>result</metric>
    <enumeratedValueSet variable="facility_default?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold_facility_B">
      <value value="120000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="duration">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="endogenous_price">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disable_external_market">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_range">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_of_A">
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_A.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy_target_ratio">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_active?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="change_sensitivity_B">
      <value value="&quot;1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dynamic_price?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy">
      <value value="&quot;target&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold_facility_A">
      <value value="120000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_B">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transportation_cost_A">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial_lag?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_B">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ratio_A">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_of_B">
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_A">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range_A">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishment">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_setup_A">
      <value value="250000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold_environment">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scale_economy">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transportation_cost_B">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_setup_B">
      <value value="250000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="change_sensitivity_A">
      <value value="&quot;1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range_B">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_external_B">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_sensitivity">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_A">
      <value value="1.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Version12_SimplifiedLP_MoreHomogenous0.02" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>seed_used</metric>
    <metric>result_A</metric>
    <metric>result_B</metric>
    <metric>result_N</metric>
    <metric>var_A</metric>
    <metric>var_B</metric>
    <metric>var_N</metric>
    <metric>ave_savings</metric>
    <metric>result</metric>
    <enumeratedValueSet variable="unit_production_B">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period_to_check_profit">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scale_economy">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transportation_cost_B">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial_lag?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_A">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy">
      <value value="&quot;target&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conversion_cost">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_setup_B">
      <value value="250000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_A">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishment">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disable_external_market">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="regulated_sensitivity" first="0" step="1" last="66"/>
    <enumeratedValueSet variable="duration">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="endogenous_price">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_setup_A">
      <value value="250000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold_facility_A">
      <value value="120000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="transportation_cost_A">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="regulated_range" first="0" step="1" last="84"/>
    <enumeratedValueSet variable="price_of_B">
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Heterogeneity?">
      <value value="&quot;other_cost:normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="change_sensitivity_A">
      <value value="&quot;1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dynamic_price?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_of_A">
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_A.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range_A">
      <value value="0.76"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_active?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_B">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ratio_A">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_external_B">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy_target_ratio">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="change_sensitivity_B">
      <value value="&quot;1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold_facility_B">
      <value value="120000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold_environment">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="facility_default?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range_B">
      <value value="0.76"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MoreHeterogeneity" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>seed_used</metric>
    <metric>result_A</metric>
    <metric>result_B</metric>
    <metric>result_N</metric>
    <metric>var_A</metric>
    <metric>var_B</metric>
    <metric>var_N</metric>
    <metric>ave_savings</metric>
    <metric>result</metric>
    <enumeratedValueSet variable="unit_production_B">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_A">
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="regulated_range" first="0" step="1" last="84"/>
    <enumeratedValueSet variable="dynamic_price?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_A">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_sensitivity">
      <value value="33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Heterogeneity?">
      <value value="&quot;other_cost:normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="period_to_check_profit">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="policy?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_B">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price_of_B">
      <value value="&quot;D:/ABM models/The rise and fall of land use X/price_B.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ratio_A">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scale_economy">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="endogenous_price">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Simulating Resilience Test 4" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>ave_savings</metric>
    <metric>amount_Dead</metric>
    <metric>amount_Full</metric>
    <metric>amount_Between</metric>
    <metric>total_production</metric>
    <metric>total_land_use</metric>
    <metric>helpers</metric>
    <enumeratedValueSet variable="heterogeneity_savings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_range">
      <value value="6"/>
      <value value="25"/>
      <value value="44"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="help?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_sensitivity">
      <value value="5"/>
      <value value="20"/>
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_shock">
      <value value="&quot;no_shock&quot;"/>
      <value value="&quot;once_productivity&quot;"/>
      <value value="&quot;series_productivity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strength_links">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Simulating Resilience Test 2" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>ave_savings</metric>
    <metric>amount_Dead</metric>
    <metric>amount_Full</metric>
    <metric>amount_Between</metric>
    <metric>total_production</metric>
    <metric>total_land_use</metric>
    <steppedValueSet variable="heterogeneity_savings" first="1" step="1" last="20"/>
    <enumeratedValueSet variable="help?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_shock">
      <value value="&quot;once_productivity&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="strength_links" first="1" step="1" last="10"/>
  </experiment>
  <experiment name="Simulating Resilience Test 5" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>ave_savings</metric>
    <metric>amount_Dead</metric>
    <metric>amount_Full</metric>
    <metric>amount_Between</metric>
    <metric>total_production</metric>
    <metric>total_land_use</metric>
    <metric>helpers</metric>
    <enumeratedValueSet variable="heterogeneity_savings">
      <value value="-4"/>
      <value value="8"/>
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_range">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="help?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_sensitivity">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_shock">
      <value value="&quot;no_shock&quot;"/>
      <value value="&quot;once_productivity&quot;"/>
      <value value="&quot;series_productivity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strength_links">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Simulating Resilience Test 5 Shocks after stable behaviours" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>ave_savings</metric>
    <metric>amount_Dead</metric>
    <metric>amount_Full</metric>
    <metric>amount_Between</metric>
    <metric>total_land_use</metric>
    <metric>helpers</metric>
    <metric>total_production</metric>
    <enumeratedValueSet variable="heterogeneity_savings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_range">
      <value value="6"/>
      <value value="25"/>
      <value value="44"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="help?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regulated_sensitivity">
      <value value="5"/>
      <value value="20"/>
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_shock">
      <value value="&quot;no_shock&quot;"/>
      <value value="&quot;once_productivity&quot;"/>
      <value value="&quot;series_productivity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strength_links">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="when_shock">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Shock-interaction-feedback_HighShockStrength 29012018" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="101"/>
    <metric>seed_used</metric>
    <metric>when_shock</metric>
    <metric>PEF_strength</metric>
    <metric>ABF_strength</metric>
    <metric>result_A</metric>
    <metric>result_B</metric>
    <metric>result_N</metric>
    <metric>result_D</metric>
    <metric>result_F</metric>
    <metric>result_P</metric>
    <metric>result_S</metric>
    <metric>after_shock_A</metric>
    <metric>after_shock_B</metric>
    <metric>after_shock_D</metric>
    <metric>after_shock_F</metric>
    <metric>after_shock_P</metric>
    <metric>after_shock_S</metric>
    <metric>ave_savings</metric>
    <metric>amount_Dead</metric>
    <metric>amount_Full</metric>
    <metric>amount_Between</metric>
    <metric>tot_area_A</metric>
    <metric>tot_area_B</metric>
    <enumeratedValueSet variable="Scenario_feedback">
      <value value="&quot;NO FEEDBACK&quot;"/>
      <value value="&quot;PEF L&quot;"/>
      <value value="&quot;PEF M&quot;"/>
      <value value="&quot;PEF H&quot;"/>
      <value value="&quot;ABF L&quot;"/>
      <value value="&quot;ABF M&quot;"/>
      <value value="&quot;ABF H&quot;"/>
      <value value="&quot;PEF L ABF L&quot;"/>
      <value value="&quot;PEF L ABF M&quot;"/>
      <value value="&quot;PEF L ABF H&quot;"/>
      <value value="&quot;PEF M ABF L&quot;"/>
      <value value="&quot;PEF M ABF M&quot;"/>
      <value value="&quot;PEF M ABF H&quot;"/>
      <value value="&quot;PEF H ABF L&quot;"/>
      <value value="&quot;PEF H ABF M&quot;"/>
      <value value="&quot;PEF H ABF H&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_interaction">
      <value value="&quot;selfish agents&quot;"/>
      <value value="&quot;heterogeneous interaction&quot;"/>
      <value value="&quot;altruistic agents&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="shock_strength">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Seed?">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_shock">
      <value value="&quot;no_shock&quot;"/>
      <value value="&quot;once_productivity&quot;"/>
      <value value="&quot;series_productivity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Random_shock?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="0129TestResult" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="101"/>
    <metric>seed_used</metric>
    <metric>when_shock</metric>
    <metric>result_A</metric>
    <metric>result_B</metric>
    <metric>result_N</metric>
    <metric>result_D</metric>
    <metric>result_F</metric>
    <metric>result_P</metric>
    <metric>result_S</metric>
    <metric>after_shock_A</metric>
    <metric>after_shock_B</metric>
    <metric>after_shock_D</metric>
    <metric>after_shock_F</metric>
    <metric>after_shock_P</metric>
    <metric>after_shock_S</metric>
    <metric>ave_savings</metric>
    <metric>amount_Dead</metric>
    <metric>amount_Full</metric>
    <metric>amount_Between</metric>
    <metric>tot_area_A</metric>
    <metric>tot_area_B</metric>
    <enumeratedValueSet variable="spatial_links_size">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ini_savings_par">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ratio_A">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="which_land_use">
      <value value="&quot;BOTH&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_B">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_B">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fixed_price_A">
      <value value="3.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="when_shock">
      <value value="38"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Heterogeneity?">
      <value value="&quot;other_cost:normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dynamic_price?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="export_transportation_cost_A">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="which_feedback">
      <value value="&quot;BOTH&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unit_production_A">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="user_defined_seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_interaction">
      <value value="&quot;altruistic agents&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PEF_strength">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="shock_strength">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Seed?">
      <value value="&quot;Random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="scale_economy">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="type_shock">
      <value value="&quot;series_productivity&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strength_links">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ABF_strength">
      <value value="44"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="required_labour_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fixed_price_B">
      <value value="3.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Random_shock?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
